@@ -9,7 +9,6 @@ from typing import Any, Dict, List, Optional
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
@@ -17,7 +16,7 @@ from annofabcli.common.cli import (
     build_annofabapi_resource_and_login,
 )
 from annofabcli.common.enums import FormatArgument
-from annofabcli.common.facade import convert_annotation_specs_labels_v2_to_v1
+from annofabcli.common.facade import AnnofabApiFacade, convert_annotation_specs_labels_v2_to_v1
 
 logger = logging.getLogger(__name__)
 
@@ -43,7 +42,7 @@ class PrintAnnotationSpecsLabel(AbstractCommandLineInterface):
             self._print_text_format_labels(labels_v1, output=output)
 
         elif arg_format in [FormatArgument.JSON.value, FormatArgument.PRETTY_JSON.value]:
-            annofabcli.utils.print_according_to_format(
+            annofabcli.common.utils.print_according_to_format(
                 target=labels_v1, arg_format=FormatArgument(arg_format), output=output
             )
 
@@ -86,7 +85,7 @@ class PrintAnnotationSpecsLabel(AbstractCommandLineInterface):
                             )
                         )
 
-        annofabcli.utils.output_string("\n".join(output_lines), output)
+        annofabcli.common.utils.output_string("\n".join(output_lines), output)
 
     def get_history_id_from_before_index(self, project_id: str, before: int) -> Optional[str]:
         histories, _ = self.service.api.get_annotation_specs_histories(project_id)
@@ -101,7 +100,6 @@ class PrintAnnotationSpecsLabel(AbstractCommandLineInterface):
         return history["history_id"]
 
     def main(self):
-
         args = self.args
 
         if args.before is not None:
