@@ -4,19 +4,20 @@ from typing import Optional
 import annofabcli
 import annofabcli.common.cli
 import annofabcli.inspection_comment.delete_inspection_comments
-import annofabcli.inspection_comment.list_inspections_with_json
+import annofabcli.inspection_comment.download_inspection_comment_json
+import annofabcli.inspection_comment.list_all_inspection_comment
 import annofabcli.inspection_comment.put_inspection_comments
 import annofabcli.inspection_comment.put_inspection_comments_simply
 
 
 def parse_args(parser: argparse.ArgumentParser):
-
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
     annofabcli.inspection_comment.delete_inspection_comments.add_parser(subparsers)
+    annofabcli.inspection_comment.download_inspection_comment_json.add_parser(subparsers)
     annofabcli.inspection_comment.list_inspections.add_parser(subparsers)
-    annofabcli.inspection_comment.list_inspections_with_json.add_parser(subparsers)
+    annofabcli.inspection_comment.list_all_inspection_comment.add_parser(subparsers)
     annofabcli.inspection_comment.put_inspection_comments.add_parser(subparsers)
     annofabcli.inspection_comment.put_inspection_comments_simply.add_parser(subparsers)
 
