@@ -12,17 +12,10 @@ import bokeh
 import bokeh.layouts
 import bokeh.palettes
 import pandas
-from bokeh.core.properties import Color
-from bokeh.models import (
-    Button,
-    CheckboxGroup,
-    CrosshairTool,
-    CustomJS,
-    DataRange1d,
-    GlyphRenderer,
-    HoverTool,
-    LinearAxis,
-)
+from bokeh.models import CrosshairTool, CustomJS, DataRange1d, HoverTool, LinearAxis
+from bokeh.models.renderers.glyph_renderer import GlyphRenderer
+from bokeh.models.widgets.buttons import Button
+from bokeh.models.widgets.groups import CheckboxGroup
 from bokeh.plotting import ColumnDataSource, figure
 
 logger = logging.getLogger(__name__)
@@ -66,8 +59,8 @@ class LineGraph:
         title: str,
         x_axis_label: str,
         y_axis_label: str,
-        plot_width: int = 1200,
-        plot_height: int = 1000,
+        width: int = 1200,
+        height: int = 1000,
         tooltip_columns: Optional[list[str]] = None,
         **figure_kwargs,
     ) -> None:
@@ -75,8 +68,8 @@ class LineGraph:
             title=title,
             x_axis_label=x_axis_label,
             y_axis_label=y_axis_label,
-            plot_width=plot_width,
-            plot_height=plot_height,
+            width=width,
+            height=height,
             **figure_kwargs,
         )
         self.title = title
@@ -92,11 +85,28 @@ class LineGraph:
 
         self.exists_secondary_y_axis = False
         self.line_glyphs: dict[str, GlyphRenderer] = {}
+        """key:凡例, value: 描画している折れ線"""
         self.marker_glyphs: dict[str, GlyphRenderer] = {}
+        """key:凡例, value: 描画しているマーカー"""
 
-    def add_secondary_y_axis(self, axis_label: str, y_range: Optional[DataRange1d] = None):
+    def add_secondary_y_axis(
+        self,
+        axis_label: str,
+        *,
+        secondary_y_axis_range: Optional[DataRange1d] = None,
+        primary_y_axis_range: Optional[DataRange1d] = None,
+    ):
         """
         第2のY軸を追加する。
+
+        Notes:
+            軸範囲を設定する理由：第1軸と第2軸の軸範囲を指定しないと、第1軸と第2軸の軸範囲が同じになり、適切な軸範囲にならないため。
+            https://qiita.com/yuji38kwmt/items/ccbee24184789686b102 参考
+
+        Args:
+            axis_label: 第2軸の名前
+            secondary_y_axis_range: 第2Y軸の軸範囲
+            primary_y_axis_range: 第1Y軸の軸範囲
         """
         self.figure.add_layout(
             LinearAxis(
@@ -105,8 +115,13 @@ class LineGraph:
             ),
             "right",
         )
-        if y_range is not None:
-            self.figure.extra_y_ranges = {self._SECONDARY_Y_RANGE_NAME: y_range}
+        if secondary_y_axis_range is not None:
+            self.figure.extra_y_ranges = {self._SECONDARY_Y_RANGE_NAME: secondary_y_axis_range}  # type: ignore
+        else:
+            self.figure.extra_y_ranges = {self._SECONDARY_Y_RANGE_NAME: DataRange1d()}  # type: ignore
+
+        if primary_y_axis_range is not None:
+            self.figure.y_range = primary_y_axis_range  # type: ignore
 
         self.exists_secondary_y_axis = True
 
@@ -186,9 +201,23 @@ class LineGraph:
         self.line_glyphs[legend_label] = line
         return line
 
-    def config_legend(self) -> None:
+    def process_after_adding_glyphs(self) -> None:
         """
-        折れ線を追加した後に、凡例の位置などを設定します。
+        折れ線などのGlyphを追加した後に実行する処理です。
+        以下を設定します。
+        * 凡例
+        * 軸の範囲
+
+        """
+        self.configure_legend()
+
+    def configure_legend(self):
+        """
+        凡例を設定します。
+
+        Notes:
+            折れ線などのGlyphを追加した後に実行する必要があります。
+
         """
         fig = self.figure
         if len(fig.legend) == 0:
@@ -207,24 +236,26 @@ class LineGraph:
         legend = fig.legend[0]
         fig.add_layout(legend, "left")
 
-    def create_button_hiding_all_lines(self) -> Button:
+    def create_button_hiding_showing_all_lines(self, is_hiding: bool) -> Button:
         """
         全ての折れ線を非表示にするボタンを生成します。
         折れ線が20個以上あると見えづらくなるので、すべて非表示にするボタンを用意しました。
+
+        Args:
+            is_hiding: Trueなら非表示ボタンを生成します。
         """
-        button = Button(label="すべての折れ線を非表示にする", button_type="primary")
+        button_label = "すべての折れ線を非表示にする" if is_hiding else "すべての折れ線を表示する"
+
+        button = Button(label=button_label, button_type="primary")
 
         glyph_list: list[GlyphRenderer] = []
         glyph_list.extend(self.line_glyphs.values())
         glyph_list.extend(self.marker_glyphs.values())
 
         args = {"glyph_list": glyph_list}
-        code = """
-            for (let glyph of glyph_list) {
-                glyph.visible = false
-            }
-        """
-        button.js_on_click(CustomJS(code=code, args=args))
+        str_is_visible = "false" if is_hiding else "true"
+        code = f"for (let glyph of glyph_list) {{glyph.visible = {str_is_visible} }}"
+        button.js_on_event("button_click", CustomJS(code=code, args=args))
         return button
 
     def create_checkbox_displaying_markers(self) -> CheckboxGroup:
@@ -243,7 +274,7 @@ class LineGraph:
                 glyph.radius = radius
             }
         """
-        checkbox_group.js_on_click(CustomJS(code=code, args=args))
+        checkbox_group.js_on_event("button_click", CustomJS(code=code, args=args))
         return checkbox_group
 
 
@@ -269,12 +300,12 @@ def get_weekly_sum(series: pandas.Series) -> pandas.Series:
     return series.rolling(MOVING_WINDOW_DAYS, min_periods=MIN_WINDOW_DAYS).sum()
 
 
-def get_color_from_palette(index: int) -> Color:
+def get_color_from_palette(index: int) -> str:
     my_palette = bokeh.palettes.Category20[20]
     return my_palette[index % len(my_palette)]
 
 
-def get_color_from_small_palette(index: int) -> Color:
+def get_color_from_small_palette(index: int) -> str:
     my_palette = bokeh.palettes.Category10[10]
     return my_palette[index % len(my_palette)]
 
