@@ -66,7 +66,7 @@ class AbstractPhaseCumulativeProductivity(abc.ABC):
             return False
 
         if len(self.default_user_id_list) == 0:
-            logger.warning(
+            logger.info(
                 f"{self.phase_name}作業したタスクが0件なので（'first_{self.phase.value}_user_id'がすべて空欄）、{output_file} を出力しません。"
             )
             return False
@@ -84,8 +84,10 @@ class AbstractPhaseCumulativeProductivity(abc.ABC):
         折れ線グラフを、HTMLファイルに出力します。
 
         Args:
-            columns_list
+            line_graph_list: 描画する折れ線グラフのlist。
+            columns_list: 描画する折れ線グラフのX軸とY軸のキー(tuple)のlist。
         """
+        assert len(line_graph_list) == len(columns_list)
 
         def get_required_columns() -> list[str]:
             """
@@ -130,12 +132,13 @@ class AbstractPhaseCumulativeProductivity(abc.ABC):
 
         graph_group_list = []
         for line_graph in line_graph_list:
-            line_graph.config_legend()
-            hide_all_button = line_graph.create_button_hiding_all_lines()
+            line_graph.process_after_adding_glyphs()
+            hide_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=True)
+            show_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=False)
             checkbox_group = line_graph.create_checkbox_displaying_markers()
 
-            widgets = bokeh.layouts.column([hide_all_button, checkbox_group])
-            graph_group = bokeh.layouts.row([line_graph.figure, widgets])
+            widgets = bokeh.layouts.column([hide_all_button, show_all_button, checkbox_group])
+            graph_group = bokeh.layouts.row([line_graph.figure, widgets])  # type: ignore
             graph_group_list.append(graph_group)
 
         write_bokeh_graph(bokeh.layouts.layout(graph_group_list), output_file)
@@ -205,6 +208,10 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         # `YYYY-MM-DDThh:mm:ss.sss+09:00`から`YYYY-MM-DD`を取得する
         # キャストする理由: 全部nanだとfloat型になって、".str"にアクセスできないため
         df["first_annotation_started_date"] = df["first_annotation_started_datetime"].astype("string").str[:10]
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df["first_annotation_started_date"] = df["first_annotation_started_date"].astype("object")
 
         # 元に戻す
         df = df.drop(["task_count"], axis=1)
@@ -443,6 +450,11 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         # キャストする理由: 全部nanだとfloat型になって、".str"にアクセスできないため
         df["first_inspection_started_date"] = df["first_inspection_started_datetime"].astype("string").str[:10]
 
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df["first_inspection_started_date"] = df["first_inspection_started_date"].astype("object")
+
         # 元に戻す
         df = df.drop(["task_count"], axis=1)
 
@@ -631,6 +643,10 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         # `YYYY-MM-DDThh:mm:ss.sss+09:00`から`YYYY-MM-DD`を取得する
         # キャストする理由: 全部nanだとfloat型になって、".str"にアクセスできないため
         df["first_acceptance_started_date"] = df["first_acceptance_started_datetime"].astype("string").str[:10]
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df["first_acceptance_started_date"] = df["first_acceptance_started_date"].astype("object")
 
         # 元に戻す
         df = df.drop(["task_count"], axis=1)
@@ -675,7 +691,7 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "task_id",
                     "first_acceptance_user_id",
                     "first_acceptance_username",
-                    "first_acceptance_started_datetime",
+                    "first_acceptance_started_date",
                     "acceptance_worktime_hour",
                     "annotation_count",
                     "inspection_comment_count",
@@ -723,7 +739,7 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "task_id",
                     "first_acceptance_user_id",
                     "first_acceptance_username",
-                    "first_acceptance_started_datetime",
+                    "first_acceptance_started_date",
                     "acceptance_worktime_hour",
                     "input_data_count",
                     "inspection_comment_count",
@@ -769,7 +785,7 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "task_id",
                     "first_acceptance_user_id",
                     "first_acceptance_username",
-                    "first_acceptance_started_datetime",
+                    "first_acceptance_started_date",
                     "acceptance_worktime_hour",
                     "inspection_comment_count",
                 ],
