@@ -14,6 +14,7 @@ import bokeh.layouts
 import bokeh.palettes
 import pandas
 from annofabapi.models import TaskPhase
+from bokeh.models.widgets.widget import Widget
 from bokeh.plotting import ColumnDataSource
 from dateutil.parser import parse
 
@@ -53,11 +54,13 @@ class AbstractPhaseProductivityPerDate(abc.ABC):
         """
         graph_group_list = []
         for line_graph in line_graph_list:
-            line_graph.config_legend()
+            line_graph.process_after_adding_glyphs()
 
-            widget_list = []
-            hide_all_button = line_graph.create_button_hiding_all_lines()
+            widget_list: list[Widget] = []
+            hide_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=True)
+            show_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=False)
             widget_list.append(hide_all_button)
+            widget_list.append(show_all_button)
 
             # マーカーがある場合は、マーカーを表示/非表示切り替えられるチェックボックスを配置する
             if len(line_graph.marker_glyphs) > 0:
@@ -65,7 +68,7 @@ class AbstractPhaseProductivityPerDate(abc.ABC):
                 widget_list.append(checkbox_group)
 
             widgets = bokeh.layouts.column(widget_list)
-            graph_group = bokeh.layouts.row([line_graph.figure, widgets])
+            graph_group = bokeh.layouts.row([line_graph.figure, widgets])  # type: ignore
             graph_group_list.append(graph_group)
 
         write_bokeh_graph(bokeh.layouts.layout(graph_group_list), output_file)
@@ -130,7 +133,7 @@ class AnnotatorProductivityPerDate(AbstractPhaseProductivityPerDate):
                 "annotation_count",
                 "inspection_comment_count",
             ]
-        ].sum()
+        ].sum(numeric_only=True)
 
         for denominator_column in ["input_data_count", "annotation_count"]:
             for phase in ["annotation", "inspection", "acceptance"]:
@@ -474,7 +477,6 @@ class AnnotatorProductivityPerDate(AbstractPhaseProductivityPerDate):
         self._plot(line_graph_list, output_file)
 
     def to_csv(self, output_file: Path) -> None:
-
         if not self._validate_df_for_output(output_file):
             return
 
@@ -544,7 +546,7 @@ class InspectorProductivityPerDate(AbstractPhaseProductivityPerDate):
                 "input_data_count",
                 "annotation_count",
             ]
-        ].sum()
+        ].sum(numeric_only=True)
 
         sum_df["inspection_worktime_hour/annotation_count"] = (
             sum_df["inspection_worktime_hour"] / sum_df["annotation_count"]
@@ -891,7 +893,7 @@ class AcceptorProductivityPerDate(AbstractPhaseProductivityPerDate):
                 "input_data_count",
                 "annotation_count",
             ]
-        ].sum()
+        ].sum(numeric_only=True)
 
         sum_df["acceptance_worktime_hour/annotation_count"] = (
             sum_df["acceptance_worktime_hour"] / sum_df["annotation_count"]
