@@ -1,3 +1,4 @@
+# pylint: disable=too-many-lines
 """
 各ユーザの合計の生産性と品質
 """
@@ -15,6 +16,8 @@ import bokeh.palettes
 import numpy
 import pandas
 from annofabapi.models import TaskPhase
+from bokeh.models.annotations import Span
+from bokeh.models.widgets.markups import Div
 from bokeh.plotting import ColumnDataSource, figure
 
 from annofabcli.common.utils import print_csv, read_multiheader_csv
@@ -397,7 +400,6 @@ class UserPerformance:
         return prior_columns
 
     def to_csv(self, output_file: Path) -> None:
-
         if not self._validate_df_for_output(output_file):
             return
 
@@ -409,8 +411,8 @@ class UserPerformance:
         print_csv(self.df[columns], str(output_file))
 
     @staticmethod
-    def _plot_average_line(fig: bokeh.plotting.Figure, value: float, dimension: str):
-        span_average_line = bokeh.models.Span(
+    def _plot_average_line(fig: figure, value: float, dimension: str):
+        span_average_line = Span(
             location=value,
             dimension=dimension,
             line_color="red",
@@ -419,7 +421,7 @@ class UserPerformance:
         fig.add_layout(span_average_line)
 
     @staticmethod
-    def _plot_quartile_line(fig: bokeh.plotting.Figure, quartile: tuple[float, float, float], dimension: str):
+    def _plot_quartile_line(fig: figure, quartile: tuple[float, float, float], dimension: str):
         """
 
         Args:
@@ -429,7 +431,7 @@ class UserPerformance:
         """
 
         for value in quartile:
-            span_average_line = bokeh.models.Span(
+            span_average_line = Span(
                 location=value,
                 dimension=dimension,
                 line_color="blue",
@@ -455,11 +457,11 @@ class UserPerformance:
             return None
 
     @staticmethod
-    def _create_div_element() -> bokeh.models.Div:
+    def _create_div_element() -> Div:
         """
         HTMLページの先頭に付与するdiv要素を生成する。
         """
-        return bokeh.models.Div(
+        return Div(
             text="""<h4>グラフの見方</h4>
             <span style="color:red;">赤線</span>：平均値<br>
             <span style="color:blue;">青線</span>：四分位数<br>
@@ -467,7 +469,7 @@ class UserPerformance:
         )
 
     @staticmethod
-    def _set_legend(fig: bokeh.plotting.Figure) -> None:
+    def _set_legend(fig: figure) -> None:
         """
         凡例の設定。
         """
@@ -561,10 +563,10 @@ class UserPerformance:
         # numpy.inf が含まれていると散布図を出力できないので置換する
         df = self.df.replace(numpy.inf, numpy.nan)
 
-        def create_figure(title: str) -> bokeh.plotting.Figure:
+        def create_figure(title: str) -> figure:
             return figure(
-                plot_width=self.PLOT_WIDTH,
-                plot_height=self.PLOT_HEIGHT,
+                width=self.PLOT_WIDTH,
+                height=self.PLOT_HEIGHT,
                 title=title,
                 x_axis_label="累計作業時間[hour]",
                 y_axis_label="アノテーションあたり作業時間[minute/annotation]",
@@ -597,6 +599,18 @@ class UserPerformance:
                 df[(f"{worktime_type.value}_worktime_hour/annotation_count", phase)] * 60
             )
 
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df = df.astype(
+            {
+                ("user_id", ""): "object",
+                ("username", ""): "object",
+                ("biography", ""): "object",
+                ("last_working_date", ""): "object",
+            }
+        )
+
         for biography_index, biography in enumerate(sorted(set(df["biography"]))):
             for fig, phase in zip(figure_list, self.phase_list):
                 filtered_df = df[
@@ -678,10 +692,10 @@ class UserPerformance:
         # numpy.inf が含まれていると散布図を出力できないので置換する
         df = self.df.replace(numpy.inf, numpy.nan)
 
-        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
+        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> figure:
             return figure(
-                plot_width=self.PLOT_WIDTH,
-                plot_height=self.PLOT_HEIGHT,
+                width=self.PLOT_WIDTH,
+                height=self.PLOT_HEIGHT,
                 title=title,
                 x_axis_label=x_axis_label,
                 y_axis_label=y_axis_label,
@@ -702,6 +716,18 @@ class UserPerformance:
 
         phase = "annotation"
 
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df = df.astype(
+            {
+                ("user_id", ""): "object",
+                ("username", ""): "object",
+                ("biography", ""): "object",
+                ("last_working_date", ""): "object",
+            }
+        )
+
         df["biography"] = df["biography"].fillna("")
         for biography_index, biography in enumerate(sorted(set(df["biography"]))):
             for column_pair, fig in zip(column_pair_list, figure_list):
@@ -788,10 +814,10 @@ class UserPerformance:
         作業時間を元に算出した生産性と品質の関係を、メンバごとにプロットする
         """
 
-        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
+        def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> figure:
             return figure(
-                plot_width=self.PLOT_WIDTH,
-                plot_height=self.PLOT_HEIGHT,
+                width=self.PLOT_WIDTH,
+                height=self.PLOT_HEIGHT,
                 title=title,
                 x_axis_label=x_axis_label,
                 y_axis_label=y_axis_label,
@@ -890,6 +916,19 @@ class UserPerformance:
         ]
         phase = TaskPhase.ANNOTATION.value
         df["biography"] = df["biography"].fillna("")
+
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df = df.astype(
+            {
+                ("user_id", ""): "object",
+                ("username", ""): "object",
+                ("biography", ""): "object",
+                ("last_working_date", ""): "object",
+            }
+        )
+
         for biography_index, biography in enumerate(sorted(set(df["biography"]))):
             for fig, column_pair in zip(figure_list, column_pair_list):
                 x_column, y_column = column_pair
@@ -914,7 +953,7 @@ class UserPerformance:
         set_tooltip()
 
         div_element = self._create_div_element()
-        div_element.text += """円の大きさ：作業時間<br>"""
+        div_element.text = div_element.text + """円の大きさ：作業時間<br>"""  # type: ignore
         write_bokeh_graph(bokeh.layouts.column([div_element] + figure_list), output_file)
 
 
