@@ -1,19 +1,21 @@
+from __future__ import annotations
+
 import argparse
 import logging
 import multiprocessing
 import sys
 from dataclasses import dataclass
 from functools import partial
-from typing import List, Optional, Tuple
+from typing import Any, List, Optional, Tuple
 
 import annofabapi
+import more_itertools
 import requests
 from annofabapi.dataclass.task import Task
-from annofabapi.models import ProjectMemberRole, TaskStatus
+from annofabapi.models import ProjectMemberRole, TaskPhase, TaskStatus
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
@@ -21,7 +23,7 @@ from annofabcli.common.cli import (
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
-from annofabcli.common.facade import TaskQuery, match_task_with_query
+from annofabcli.common.facade import AnnofabApiFacade, TaskQuery, match_task_with_query
 from annofabcli.common.utils import add_dryrun_prefix
 
 logger = logging.getLogger(__name__)
@@ -35,14 +37,26 @@ class User:
 
 
 class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
-    def __init__(self, service: annofabapi.Resource, all_yes: bool = False):
+    def __init__(self, service: annofabapi.Resource, project_id: str, all_yes: bool = False):
         self.service = service
+        self.project_id = project_id
         self.facade = AnnofabApiFacade(service)
+
+        self._project_members_dict: Optional[dict[str, dict[str, Any]]] = None
+        """プロジェクトメンバー情報を保持する変数"""
+
         AbstractCommandLineWithConfirmInterface.__init__(self, all_yes)
 
+    def get_project_member_from_account_id(self, account_id: str) -> Optional[dict[str, Any]]:
+        """account_idからプロジェクトメンバを取得します。"""
+        if self._project_members_dict is None:
+            project_member_list = self.service.wrapper.get_all_project_members(self.project_id)
+            self._project_members_dict = {e["account_id"]: e for e in project_member_list}
+
+        return self._project_members_dict.get(account_id)
+
     def cancel_acceptance_for_task(
         self,
-        project_id: str,
         task_id: str,
         acceptor: Optional[User] = None,
         assign_last_acceptor: bool = True,
@@ -50,15 +64,15 @@ class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
         task_index: Optional[int] = None,
         dryrun: bool = False,
     ) -> bool:
-        def get_user_id(user: Optional[User]) -> Optional[str]:
-            return user.user_id if user is not None else None
-
         logging_prefix = f"{task_index + 1} 件目" if task_index is not None else ""
 
         try:
-            task, _ = self.service.api.get_task(project_id, task_id)
+            task = self.service.wrapper.get_task_or_none(self.project_id, task_id)
+            if task is None:
+                logger.warning(f"{logging_prefix}: task_id='{task_id}'のタスクは存在しないので、スキップします。")
+                return False
 
-            if task["status"] != TaskStatus.COMPLETE.value:
+            if task["phase"] != TaskPhase.ACCEPTANCE.value or task["status"] != TaskStatus.COMPLETE.value:
                 logger.warning(
                     f"{logging_prefix}: task_id = {task_id} は受入完了でありません。"
                     f"status = {task['status']}, phase={task['phase']}"
@@ -67,16 +81,19 @@ class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
 
             actual_acceptor: Optional[User] = None
             if assign_last_acceptor:
+                # 最後の受入フェーズの担当者の情報を取得する
                 acceptor_account_id = task["account_id"]
                 if acceptor_account_id is not None:
-                    member = self.facade.get_project_member_from_account_id(project_id, acceptor_account_id)
+                    member = self.get_project_member_from_account_id(acceptor_account_id)
                     if member is not None:
                         actual_acceptor = User(
                             account_id=member["account_id"], user_id=member["user_id"], username=member["username"]
                         )
                     else:
-                        logger.warning(f"account_id='{acceptor_account_id}' であるユーザは見つかりませんでした。")
-                        return False
+                        logger.warning(
+                            f"{logging_prefix}: task_id = {task_id} の最後の受入フェーズを担当したユーザ"
+                            f"（account_id='{acceptor_account_id}'）は、プロジェクトメンバーでないので、担当者を割り当てません。"
+                        )
             else:
                 actual_acceptor = acceptor
 
@@ -84,56 +101,55 @@ class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
                 logger.debug(f"{logging_prefix} : task_id = {task_id} : TaskQueryの条件にマッチしないため、スキップします。")
                 return False
 
-            if not self.confirm_processing(
-                f"{logging_prefix}: task_id = {task_id} のタスクの受入を取り消しますか？ "
-                f"user_id = '{get_user_id(actual_acceptor)}' のユーザに割り当てます。"
-            ):
+            if not self.confirm_processing(f"{logging_prefix}: task_id = {task_id} のタスクの受入完了状態を取り消しますか？ "):
                 return False
 
             logger.debug(
-                f"{logging_prefix}: task_id = {task_id} のタスクの受入を取り消し、"
-                f"user_id = '{get_user_id(actual_acceptor)}' のユーザに割り当てます。"
+                f"{logging_prefix}: task_id = {task_id} のタスクの受入完了状態を取り消します。"
+                + (
+                    f"タスクの担当者は {actual_acceptor.username}({actual_acceptor.user_id}) です。"
+                    if actual_acceptor is not None
+                    else "タスクの担当者は未割り当てです。"
+                )  # noqa: E501
             )
-            request_body = {
-                "status": "not_started",
-                "account_id": actual_acceptor.account_id if actual_acceptor is not None else None,
-                "last_updated_datetime": task["updated_datetime"],
-            }
+            operator_account_id = actual_acceptor.account_id if actual_acceptor is not None else None
             if not dryrun:
-                self.service.api.operate_task(project_id, task_id, request_body=request_body)
+                self.service.wrapper.cancel_completed_task(
+                    self.project_id, task_id, operator_account_id=operator_account_id
+                )
             logger.info(f"{logging_prefix} : task_id = {task_id} の受け入れ取り消しが成功しました。")
             return True
 
-        except requests.exceptions.HTTPError as e:
-            logger.warning(f"{logging_prefix} : task_id = {task_id} の受け入れ取り消しに失敗しました。")
-            logger.warning(e)
+        except requests.exceptions.HTTPError:
+            logger.warning(f"{logging_prefix} : task_id = {task_id} の受け入れ取り消しに失敗しました。", exc_info=True)
             return False
 
     def cancel_acceptance_for_wrapper(
         self,
         tpl: Tuple[int, str],
-        project_id: str,
         acceptor: Optional[User] = None,
         assign_last_acceptor: bool = True,
         task_query: Optional[TaskQuery] = None,
         dryrun: bool = False,
     ) -> bool:
         task_index, task_id = tpl
-        return self.cancel_acceptance_for_task(
-            project_id=project_id,
-            task_id=task_id,
-            acceptor=acceptor,
-            assign_last_acceptor=assign_last_acceptor,
-            task_query=task_query,
-            task_index=task_index,
-            dryrun=dryrun,
-        )
+        try:
+            return self.cancel_acceptance_for_task(
+                task_id=task_id,
+                acceptor=acceptor,
+                assign_last_acceptor=assign_last_acceptor,
+                task_query=task_query,
+                task_index=task_index,
+                dryrun=dryrun,
+            )
+        except Exception:  # pylint: disable=broad-except
+            logger.warning(f"タスク'{task_id}'の受け入れ取り消しに失敗しました。", exc_info=True)
+            return False
 
     def cancel_acceptance_for_task_list(
         self,
-        project_id: str,
         task_id_list: List[str],
-        acceptor_user_id: Optional[str] = None,
+        acceptor: Optional[User] = None,
         assign_last_acceptor: bool = True,
         task_query: Optional[TaskQuery] = None,
         parallelism: Optional[int] = None,
@@ -148,24 +164,16 @@ class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
             acceptor_user_id: 再度受入を担当させたいユーザのuser_id. Noneならば、未割り当てにする
             assign_last_acceptor: trueなら最後の受入担当者に割り当てる
         """
+        assert not (assign_last_acceptor and acceptor is not None)
         logger.info(f"受け入れを取り消すタスク数: {len(task_id_list)}")
 
         if task_query is not None:
-            task_query = self.facade.set_account_id_of_task_query(project_id, task_query)
-
-        acceptor: Optional[User] = None
-        if acceptor_user_id is not None:
-            member = self.facade.get_project_member_from_user_id(project_id, acceptor_user_id)
-            if member is not None:
-                acceptor = User(account_id=member["account_id"], user_id=member["user_id"], username=member["username"])
-            else:
-                raise RuntimeError(f"user_id='{acceptor_user_id}' であるプロジェクトメンバは見つかりませんでした。")
+            task_query = self.facade.set_account_id_of_task_query(self.project_id, task_query)
 
         success_count = 0
         if parallelism is not None:
             partial_func = partial(
                 self.cancel_acceptance_for_wrapper,
-                project_id=project_id,
                 acceptor=acceptor,
                 assign_last_acceptor=assign_last_acceptor,
                 task_query=task_query,
@@ -179,29 +187,32 @@ class CancelAcceptanceMain(AbstractCommandLineWithConfirmInterface):
             # 逐次処理
             success_count = 0
             for task_index, task_id in enumerate(task_id_list):
-                result = self.cancel_acceptance_for_task(
-                    project_id,
-                    task_id,
-                    task_index=task_index,
-                    acceptor=acceptor,
-                    assign_last_acceptor=assign_last_acceptor,
-                    task_query=task_query,
-                    dryrun=dryrun,
-                )
-                if result:
-                    success_count += 1
+                try:
+                    result = self.cancel_acceptance_for_task(
+                        task_id,
+                        task_index=task_index,
+                        acceptor=acceptor,
+                        assign_last_acceptor=assign_last_acceptor,
+                        task_query=task_query,
+                        dryrun=dryrun,
+                    )
+                    if result:
+                        success_count += 1
+                except Exception:  # pylint: disable=broad-except
+                    logger.warning(f"タスク'{task_id}'の受け入れ取り消しに失敗しました。", exc_info=True)
+                    continue
 
         logger.info(f"{success_count} / {len(task_id_list)} 件 受け入れ取り消しに成功しました。")
 
 
 class CancelAcceptance(AbstractCommandLineInterface):
-    @staticmethod
-    def validate(args: argparse.Namespace) -> bool:
-        COMMON_MESSAGE = "annofabcli task cancel_acceptance: error:"
+    COMMON_MESSAGE = "annofabcli task cancel_acceptance: error:"
 
+    @classmethod
+    def validate(cls, args: argparse.Namespace) -> bool:
         if args.parallelism is not None and not args.yes:
             print(
-                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず ``--yes`` を指定してください。",
+                f"{cls.COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、'--yes' を指定してください。",
                 file=sys.stderr,
             )
             return False
@@ -218,18 +229,36 @@ class CancelAcceptance(AbstractCommandLineInterface):
 
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
 
-        assign_last_acceptor = not args.not_assign and args.assigned_acceptor_user_id is None
+        assigned_acceptor_user_id: Optional[str] = args.assigned_acceptor_user_id
+
+        # 最後の受入フェーズの担当者に割り当てるか否か
+        assign_last_acceptor = not args.not_assign and assigned_acceptor_user_id is None
+
+        # 受入担当者の情報を取得する
+        acceptor: Optional[User] = None  # 受入担当者
+        if assigned_acceptor_user_id is not None:
+            project_member_list = self.service.wrapper.get_all_project_members(args.project_id)
+            member = more_itertools.first_true(
+                project_member_list, pred=lambda e: e["user_id"] == assigned_acceptor_user_id
+            )
+            if member is None:
+                print(
+                    f"{self.COMMON_MESSAGE} argument --assigned_acceptor_user_id: プロジェクトメンバーに user_id='{assigned_acceptor_user_id}'メンバーは存在しません",  # noqa: E501
+                    file=sys.stderr,
+                )
+                sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
+            else:
+                acceptor = User(account_id=member["account_id"], user_id=member["user_id"], username=member["username"])
 
         dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
         task_query: Optional[TaskQuery] = TaskQuery.from_dict(dict_task_query) if dict_task_query is not None else None
 
         super().validate_project(args.project_id, [ProjectMemberRole.OWNER])
-        main_obj = CancelAcceptanceMain(self.service, all_yes=args.yes)
+        main_obj = CancelAcceptanceMain(self.service, project_id=args.project_id, all_yes=args.yes)
         main_obj.cancel_acceptance_for_task_list(
-            args.project_id,
             task_id_list,
-            acceptor_user_id=args.assigned_acceptor_user_id,
             assign_last_acceptor=assign_last_acceptor,
+            acceptor=acceptor,
             task_query=task_query,
             parallelism=args.parallelism,
             dryrun=args.dryrun,
