@@ -4,18 +4,17 @@ from typing import Optional
 import annofabcli
 import annofabcli.common.cli
 import annofabcli.task_history.download_task_history_json
+import annofabcli.task_history.list_all_task_history
 import annofabcli.task_history.list_task_history
-import annofabcli.task_history.list_task_history_with_json
 
 
 def parse_args(parser: argparse.ArgumentParser):
-
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
     annofabcli.task_history.download_task_history_json.add_parser(subparsers)
     annofabcli.task_history.list_task_history.add_parser(subparsers)
-    annofabcli.task_history.list_task_history_with_json.add_parser(subparsers)
+    annofabcli.task_history.list_all_task_history.add_parser(subparsers)
 
 
 def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
